source("time.r")
 
test.name <- "prg-data"

# Example of data simulation, output, input, and analysis.

N <- 10000
V <- 10

sim <- test.cmp (function ()
{ 
  df <- data.frame(matrix(NA,N,V))
  colnames(df) <- paste("VAR",1:V,sep="")
  for (i in 1:V)
  { if (i %% 4 == 0) 
      df[,i] <- rnorm(N,0.1*(i+(1:N)),25)
    else if (i %% 4 == 1)
      df[,i] <- runif(N) < 0.7
    else if (i %% 4 == 2)
      df[,i] <- paste("xyz",rpois(N,3),sep="")
    else
      df[,i] <- 0.01*(1:N) + rpois(N,3)
  }
  df
})

analyse <- test.cmp (function (df,pr=FALSE)
{
  s <- summary(df)
  if (pr) print(s)
  df2 <- df[,!sapply(df,is.character)]
  m <- lm (VAR4 ~ ., data = df2)
  if (pr) print(m)
  sm <- summary(m)
  if (pr) print(sm)
  coef(m)
})

set.seed(1)

sys.time (for (i in 1:50) data <- sim())

sys.time (for (i in 1:25) write.table(data,"test-data-file",quote=FALSE))

sys.time (for (i in 1:50) rdata <- read.table("test-data-file",head=TRUE,
                                              stringsAsFactors=FALSE))

sys.time (for (i in 1:150) a <- analyse(rdata))
analyse(rdata,TRUE)
print(a)
