source("time.r")

# Example of iteratively solving a simple PDE modeling heat flow in
# a rectangle with temperatures fixed at the edges.


# Create the initial configuration of temperatures on an nr by nc
# rectangle.

initial_temperatures <- test.cmp(function (nr,nc)
{
    M <- matrix (0, nrow=nr, ncol=nc)
    for (i in 1:nr) M[i,nc] <- 1
    for (j in 1:nc) M[nr,j] <- 1
    M
})


# Update the configuration of temperatures by one time step, returning
# the new configuration.

heat_flow <- test.cmp(function (M)
{
    R <- M
    for (i in 2:(nrow(M)-1)) {
        for (j in 2:(ncol(M)-1)) {
            R[i,j] <- (M[i,j] + M[i-1,j] + M[i,j-1] + M[i+1,j] + M[i,j+1]) / 5
        }
    }
    R
})


# Test function.

doit <- test.cmp(function (nr,nc,k)
{
    M <- initial_temperatures(nr,nc)
    for (i in 1:k) M <- heat_flow(M)
    M
})

test.name <- "prg-heat"

sys.time(r <- doit(10,10,30000))
print(round(r,2))

sys.time(r <- doit(100,100,300))
print(round(r[91:100,91:100],2))

